Method: InlineKeyboardButton#switch_inline_query

Defined in:
lib/objects/inlinekeyboardbutton.rb

#switch_inline_queryObject

Optional. If set, pressing the button will prompt the user to select one of their chats, open that chat and insert the bot’s username and the specified inline query in the input field. Can be empty, in which case just the bot’s username will be inserted.



38
39
40
# File 'lib/objects/inlinekeyboardbutton.rb', line 38

def switch_inline_query
  @button.switch_inline_query
end